==> python-dateparser-0.7.6-1-any.pkg.tar.xz: usr/lib/python3.8/site-packages/dateparser/data/date_translation_data/hi.py <==
# -*- coding: utf-8 -*-
info = {
    "name": "hi",
    "date_order": "DMY",
    "january": [
        "जनवरी",
        "जन॰"
    ],
    "february": [
        "फ़रवरी",
        "फ़र॰"
    ],
    "march": [
        "मार्च"
    ],
    "april": [
        "अप्रैल"
    ],
    "may": [
        "मई"
    ],
    "june": [
        "जून"
    ],
    "july": [
        "जुलाई",
        "जुल॰"
    ],
    "august": [
        "अगस्त",
        "अग॰"
    ],
    "september": [
        "सितंबर",
        "सित॰",
        "सितम्बर"
    ],
    "october": [
        "अक्तूबर",
        "अक्तू॰",
        "अक्टूबर"
    ],
    "november": [
        "नवंबर",
        "नव॰",
        "नवम्बर"
    ],
    "december": [
        "दिसंबर",
        "दिस॰",
        "दिसम्बर"
    ],
    "monday": [
        "सोमवार",
        "सोम"
    ],
    "tuesday": [
        "मंगलवार",
        "मंगल"
    ],
    "wednesday": [
        "बुधवार",
        "बुध"
    ],
    "thursday": [
        "गुरुवार",
        "गुरु"
    ],
    "friday": [
        "शुक्रवार",
        "शुक्र"
    ],
    "saturday": [
        "शनिवार",
        "शनि"
    ],
    "sunday": [
        "रविवार",
        "रवि"
    ],
    "am": [
        "पूर्वाह्न"
    ],
    "pm": [
        "अपराह्न"
    ],
    "year": [
        "वर्ष",
        "साल",
        "वर्षों"
    ],
    "month": [
        "माह",
        "महीना",
        "मास",
        "महीने"
    ],
    "week": [
        "सप्ताह"
    ],
    "day": [
        "दिन",
        "दिवस"
    ],
    "hour": [
        "घंटा",
        "घं",
        "घंटे"
    ],
    "minute": [
        "मिनट",
        "मि"
    ],
    "second": [
        "सेकंड",
        "से"
    ],
    "relative-type": {
        "1 year ago": [
            "पिछला वर्ष"
        ],
        "0 year ago": [
            "इस वर्ष"
        ],
        "in 1 year": [
            "अगला वर्ष"
        ],
        "1 month ago": [
            "पिछला माह"
        ],
        "0 month ago": [
            "इस माह"
        ],
        "in 1 month": [
            "अगला माह"
        ],
        "1 week ago": [
            "पिछला सप्ताह"
        ],
        "0 week ago": [
            "इस सप्ताह"
        ],
        "in 1 week": [
            "अगला सप्ताह"
        ],
        "1 day ago": [
            "कल"
        ],
        "0 day ago": [
            "आज"
        ],
        "in 1 day": [
            "कल"
        ],
        "0 hour ago": [
            "यह घंटा"
        ],
        "0 minute ago": [
            "यह मिनट"
        ],
        "0 second ago": [
            "अब"
        ],
        "2 day ago": [
            "परसों"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "(\\d+) वर्ष में"
        ],
        "\\1 year ago": [
            "(\\d+) वर्ष पहले"
        ],
        "in \\1 month": [
            "(\\d+) माह में"
        ],
        "\\1 month ago": [
            "(\\d+) माह पहले"
        ],
        "in \\1 week": [
            "(\\d+) सप्ताह में"
        ],
        "\\1 week ago": [
            "(\\d+) सप्ताह पहले"
        ],
        "in \\1 day": [
            "(\\d+) दिन में"
        ],
        "\\1 day ago": [
            "(\\d+) दिन पहले"
        ],
        "in \\1 hour": [
            "(\\d+) घंटे में",
            "(\\d+) घं में"
        ],
        "\\1 hour ago": [
            "(\\d+) घंटे पहले",
            "(\\d+) घं पहले"
        ],
        "in \\1 minute": [
            "(\\d+) मिनट में",
            "(\\d+) मि में"
        ],
        "\\1 minute ago": [
            "(\\d+) मिनट पहले",
            "(\\d+) मि पहले"
        ],
        "in \\1 second": [
            "(\\d+) सेकंड में",
            "(\\d+) से में"
        ],
        "\\1 second ago": [
            "(\\d+) सेकंड पहले",
            "(\\d+) से पहले"
        ]
    },
    "locale_specific": {},
    "skip": [
        "बजे",
        "सन्",
        "को",
        "के",
        "से",
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ],
    "sentence_splitter_group": 3,
    "ago": [
        "पहले",
        "पूर्व"
    ],
    "in": [
        "में",
        "बाद"
    ]
}

==> python-dateparser-1.1.1-1-any.pkg.tar.xz: usr/lib/python3.10/site-packages/dateparser/data/date_translation_data/hi.py <==
info = {
    "name": "hi",
    "date_order": "DMY",
    "january": [
        "जनवरी",
        "जन॰"
    ],
    "february": [
        "फ़रवरी",
        "फ़र॰"
    ],
    "march": [
        "मार्च"
    ],
    "april": [
        "अप्रैल"
    ],
    "may": [
        "मई"
    ],
    "june": [
        "जून"
    ],
    "july": [
        "जुलाई",
        "जुल॰"
    ],
    "august": [
        "अगस्त",
        "अग॰"
    ],
    "september": [
        "सितंबर",
        "सित॰",
        "सितम्बर"
    ],
    "october": [
        "अक्तूबर",
        "अक्तू॰",
        "अक्टूबर"
    ],
    "november": [
        "नवंबर",
        "नव॰",
        "नवम्बर"
    ],
    "december": [
        "दिसंबर",
        "दिस॰",
        "दिसम्बर"
    ],
    "monday": [
        "सोम",
        "सोमवार"
    ],
    "tuesday": [
        "मंगल",
        "मंगलवार"
    ],
    "wednesday": [
        "बुध",
        "बुधवार"
    ],
    "thursday": [
        "गुरु",
        "गुरुवार"
    ],
    "friday": [
        "शुक्र",
        "शुक्रवार"
    ],
    "saturday": [
        "शनि",
        "शनिवार"
    ],
    "sunday": [
        "रवि",
        "रविवार"
    ],
    "am": [
        "पूर्वाह्न"
    ],
    "pm": [
        "अपराह्न"
    ],
    "year": [
        "वर्ष",
        "साल",
        "वर्षों"
    ],
    "month": [
        "माह",
        "महीना",
        "मास",
        "महीने"
    ],
    "week": [
        "सप्ताह"
    ],
    "day": [
        "दिन",
        "दिवस"
    ],
    "hour": [
        "घं",
        "घंटा",
        "घंटे"
    ],
    "minute": [
        "मि",
        "मिनट"
    ],
    "second": [
        "से",
        "सेकंड"
    ],
    "relative-type": {
        "0 day ago": [
            "आज"
        ],
        "0 hour ago": [
            "यह घंटा"
        ],
        "0 minute ago": [
            "यह मिनट"
        ],
        "0 month ago": [
            "इस माह"
        ],
        "0 second ago": [
            "अब"
        ],
        "0 week ago": [
            "इस सप्ताह"
        ],
        "0 year ago": [
            "इस वर्ष"
        ],
        "1 day ago": [
            "कल"
        ],
        "1 month ago": [
            "पिछला माह"
        ],
        "1 week ago": [
            "पिछला सप्ताह"
        ],
        "1 year ago": [
            "पिछला वर्ष"
        ],
        "in 1 day": [
            "कल"
        ],
        "in 1 month": [
            "अगला माह"
        ],
        "in 1 week": [
            "अगला सप्ताह"
        ],
        "in 1 year": [
            "अगला वर्ष"
        ],
        "2 day ago": [
            "परसों"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "(\\d+) दिन पहले"
        ],
        "\\1 hour ago": [
            "(\\d+) घं पहले",
            "(\\d+) घंटे पहले"
        ],
        "\\1 minute ago": [
            "(\\d+) मि पहले",
            "(\\d+) मिनट पहले"
        ],
        "\\1 month ago": [
            "(\\d+) माह पहले"
        ],
        "\\1 second ago": [
            "(\\d+) से पहले",
            "(\\d+) सेकंड पहले"
        ],
        "\\1 week ago": [
            "(\\d+) सप्ताह पहले"
        ],
        "\\1 year ago": [
            "(\\d+) वर्ष पहले"
        ],
        "in \\1 day": [
            "(\\d+) दिन में"
        ],
        "in \\1 hour": [
            "(\\d+) घं में",
            "(\\d+) घंटे में"
        ],
        "in \\1 minute": [
            "(\\d+) मि में",
            "(\\d+) मिनट में"
        ],
        "in \\1 month": [
            "(\\d+) माह में"
        ],
        "in \\1 second": [
            "(\\d+) से में",
            "(\\d+) सेकंड में"
        ],
        "in \\1 week": [
            "(\\d+) सप्ताह में"
        ],
        "in \\1 year": [
            "(\\d+) वर्ष में"
        ]
    },
    "locale_specific": {},
    "skip": [
        "के",
        "को",
        "बजे",
        "सन्",
        "से",
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ],
    "sentence_splitter_group": 3,
    "ago": [
        "पहले",
        "पूर्व"
    ],
    "in": [
        "में",
        "बाद"
    ]
}
